# Generated by Django 4.1.5 on 2023-03-02 19:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('music', '0012_album_allmusic_id_album_discogs_id_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='album',
            name='theaudiodb_score',
            field=models.FloatField(blank=True, null=True),
        ),
    ]
